Particle class

Constructors

Particle({required Color color, required Size parentSize, required AnimationController controller})

Properties

color Color
final
controller AnimationController
final
hashCode int
The hash code for this object.
no setterinherited
parentSize Size
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited